@@ -42,8 +42,14 @@ impl<W: io::Write> Emitter<W> {
 mod tests {
     use crate::*;
 
-    fn list(values: &[&str]) -> List {
-        values.iter().copied().map(Into::into).collect()
+    impl Into<Value> for &[&str] {
+        fn into(self) -> Value {
+            self.iter()
+                .copied()
+                .map(Into::into)
+                .collect::<Vec<_>>()
+                .into()
+        }
     }
 
     #[test]
@@ -54,13 +60,13 @@ mod tests {
 
     #[test]
     fn test_list() {
-        let encoded = to_string(&[Mapping::new("key", list(&["value"]))], 0);
+        let encoded = to_string(&[Mapping::new("key", ["value"].as_ref())], 0);
         assert_eq!(encoded, "key\n- value\n");
     }
 
     #[test]
     fn test_list_indent() {
-        let encoded = to_string(&[Mapping::new("key", list(&["value1", "value2"]))], 2);
+        let encoded = to_string(&[Mapping::new("key", ["value1", "value2"].as_ref())], 2);
         assert_eq!(encoded, "key\n  - value1\n  - value2\n");
     }
 
@@ -75,9 +81,9 @@ mod tests {
         let encoded = to_string(
             &[
                 Mapping::new("key1", "value1"),
-                Mapping::new("key2", list(&["value2"])),
+                Mapping::new("key2", ["value2"].as_ref()),
                 Mapping::new("key3", "value3"),
-                Mapping::new("key4", list(&["value4"])),
+                Mapping::new("key4", ["value4"].as_ref()),
             ],
             2,
         );
